==> jc-1.4.0.tar.gz: jas/Catchtable.h <==
// public class jas.Catchtable

// class file dependencies
// @dep_class d93896760e183b63 jas_Catchtable
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_Catchtable_H_
#define _JC_jas_Catchtable_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_CatchEntry$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_Catchtable$sub_refs	_jc_jas_Catchtable$sub_refs;
typedef struct _jc_jas_Catchtable$sub_nonrefs	_jc_jas_Catchtable$sub_nonrefs;
typedef struct _jc_jas_Catchtable$refs	_jc_jas_Catchtable$refs;
typedef struct _jc_jas_Catchtable$nonrefs	_jc_jas_Catchtable$nonrefs;
typedef struct _jc_jas_Catchtable$object	_jc_jas_Catchtable$object;

typedef const struct _jc_jas_Catchtable$vmethods	_jc_jas_Catchtable$vmethods;
typedef const struct _jc_jas_Catchtable$vtable	_jc_jas_Catchtable$vtable;
typedef const struct _jc_jas_Catchtable$vtype	_jc_jas_Catchtable$vtype;

// Constructors
extern void _jc_jas_Catchtable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_Catchtable$object *);

// Virtual methods
extern void _jc_jas_Catchtable$method$addEntry$7c05dbd6bcf4743d(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_CatchEntry$object *);
extern void _jc_jas_Catchtable$method$addEntry$9fadb84958217e77(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *);
extern void _jc_jas_Catchtable$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_Catchtable$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_Catchtable$object *);
extern void _jc_jas_Catchtable$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_Catchtable$method_info$addEntry$7c05dbd6bcf4743d;
extern _jc_method _jc_jas_Catchtable$method_info$addEntry$9fadb84958217e77;
extern _jc_method _jc_jas_Catchtable$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_Catchtable$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_Catchtable$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_Catchtable$vmethods {
	void	(*addEntry$7c05dbd6bcf4743d)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_CatchEntry$object *);
	void	(*addEntry$9fadb84958217e77)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_Catchtable$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_Catchtable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Catchtable$vmethods	jas_Catchtable;
};

// Vtype
struct _jc_jas_Catchtable$vtype {
	_jc_type			type;
	_jc_jas_Catchtable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_Catchtable$sub_refs {
	struct _jc_java_util_Vector$object	*entries;
};

// Reference instance fields (object)
struct _jc_jas_Catchtable$refs {
    _jc_jas_Catchtable$sub_refs	jas_Catchtable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_Catchtable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_Catchtable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Catchtable$sub_nonrefs	jas_Catchtable;
};

// Object instance structure
struct _jc_jas_Catchtable$object {
	_jc_jas_Catchtable$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_Catchtable$vtype	*vtype;
	_jc_jas_Catchtable$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_Catchtable$vtype _jc_jas_Catchtable$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_Catchtable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_Catchtable$class_object;

#endif	/* _JC_jas_Catchtable_H_ */

==> jc-1.4.6.tar.gz: jas/Catchtable.h <==
// public class jas.Catchtable

// class file dependencies
// @dep_class d93896760e183b63 jas_Catchtable
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_Catchtable_H_
#define _JC_jas_Catchtable_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_CatchEntry$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_Catchtable$sub_refs	_jc_jas_Catchtable$sub_refs;
typedef struct _jc_jas_Catchtable$sub_nonrefs	_jc_jas_Catchtable$sub_nonrefs;
typedef struct _jc_jas_Catchtable$refs	_jc_jas_Catchtable$refs;
typedef struct _jc_jas_Catchtable$nonrefs	_jc_jas_Catchtable$nonrefs;
typedef struct _jc_jas_Catchtable$object	_jc_jas_Catchtable$object;

typedef const struct _jc_jas_Catchtable$vmethods	_jc_jas_Catchtable$vmethods;
typedef const struct _jc_jas_Catchtable$vtable	_jc_jas_Catchtable$vtable;
typedef const struct _jc_jas_Catchtable$vtype	_jc_jas_Catchtable$vtype;

// Constructors
extern void _jc_jas_Catchtable$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_Catchtable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_Catchtable$method$addEntry$7c05dbd6bcf4743d(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_CatchEntry$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Catchtable$method$addEntry$9fadb84958217e77(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Catchtable$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_Catchtable$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_Catchtable$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Catchtable$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_Catchtable$method_info$addEntry$7c05dbd6bcf4743d;
extern _jc_method _jc_jas_Catchtable$method_info$addEntry$9fadb84958217e77;
extern _jc_method _jc_jas_Catchtable$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_Catchtable$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_Catchtable$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_Catchtable$vmethods {
	void	(*addEntry$7c05dbd6bcf4743d)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_CatchEntry$object *) _JC_JCNI_ATTR;
	void	(*addEntry$9fadb84958217e77)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_Label$object *, struct _jc_jas_CP$object *) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_Catchtable$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_Catchtable$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_Catchtable$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Catchtable$vmethods	jas_Catchtable;
};

// Vtype
struct _jc_jas_Catchtable$vtype {
	_jc_type			type;
	_jc_jas_Catchtable$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_Catchtable$sub_refs {
	struct _jc_java_util_Vector$object	*entries;
};

// Reference instance fields (object)
struct _jc_jas_Catchtable$refs {
    _jc_jas_Catchtable$sub_refs	jas_Catchtable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_Catchtable$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_Catchtable$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Catchtable$sub_nonrefs	jas_Catchtable;
};

// Object instance structure
struct _jc_jas_Catchtable$object {
	_jc_jas_Catchtable$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_Catchtable$vtype	*vtype;
	_jc_jas_Catchtable$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_Catchtable$vtype _jc_jas_Catchtable$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_Catchtable, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_Catchtable$class_object;

#endif	/* _JC_jas_Catchtable_H_ */
